Package: SigCheck
Type: Package
Title: Check a gene signature's prognostic performance against random
        signatures, known signatures, and permuted data/metadata
Version: 2.44.0
Author: Rory Stark <bioconductor@starkhome.com> and 
         Justin Norden 
Maintainer: Rory Stark <bioconductor@starkhome.com>
Description: While gene signatures are frequently used to predict phenotypes
        (e.g. predict prognosis of cancer patients), it it not always
        clear how optimal or meaningful they are (cf David Venet,
        Jacques E. Dumont, and Vincent Detours' paper "Most Random Gene
        Expression Signatures Are Significantly Associated with Breast
        Cancer Outcome"). Based on suggestions in that paper,
        SigCheck accepts a data set (as an ExpressionSet) and a gene
        signature, and compares its performance on survival and/or 
        classification tasks against 
        a) random gene signatures of the same length; 
        b) known, related and unrelated gene signatures; 
        and c) permuted data and/or metadata.
License: Artistic-2.0
LazyLoad: yes
Depends: R (>= 4.0.0), MLInterfaces, Biobase, e1071, BiocParallel,
        survival
Imports: graphics, stats, utils, methods
Suggests: BiocStyle, breastCancerNKI, qusage
biocViews: GeneExpression, Classification, GeneSetEnrichment
git_url: https://git.bioconductor.org/packages/SigCheck
git_branch: RELEASE_3_23
git_last_commit: 3d8182f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:42:17 UTC; biocbuild
