#import(MLInterfaces, Biobase, e1071, BiocParallel)

export(sigCheck)
export(sigCheckRandom)
export(sigCheckPermuted)
export(sigCheckKnown)
export(sigCheckPlot)
export(sigCheckAll)

#exportMethods(
# "checkType",                          
# "classes",                            
# "annotation",                         
# "survival",                           
# "signature",                          
# "validationSamples",                  
# "survivalMethod",                     
# "threshold",                          
# "survivalType",                       
# "timeUnits",                          
# "survivalScores",                     
# "survivalConfusionMatrix",            
# "survivalClassificationScore",        
# "survivalPval",                       
# "survivalTrainingScores",             
# "survivalTrainingConfusionMatrix",    
# "survivalTrainingClassificationScore",
# "survivalTrainingPval",               
# "classifierMethod",                   
# "sigPerformance",                     
# "confusion",            
# "modeVal",
# "modePerformance",                    
# "classifier"  
#)

exportClasses(
    "SigCheckObject"
)


#Imports: AnnotationDbi, Biobase, BiocGenerics, BiocParallel, graphics,
#         IRanges, MLInterfaces, S4Vectors, stats, utils

importMethodsFrom(Biobase, exprs, "exprs<-", featureData, varLabels,
                  varMetadata, sampleNames)

importMethodsFrom(BiocParallel, bplapply)

importMethodsFrom(MLInterfaces, confuMat, MLearn)

importFrom(graphics, abline, legend, par)

importFrom(MLInterfaces, xvalSpec)

importFrom(stats, ecdf, formula)

importFrom(utils, data)

importFrom(MLInterfaces, svmI, trainScores, testScores)

importFrom(survival, Surv, survfit, survdiff)

importFrom(e1071, svm)

import(methods)

importFrom("graphics", "plot", "text")

importFrom("stats", "density", "median", "pchisq", "prcomp",
             "quantile")
